@@ -5,7 +5,7 @@ package Test::Sah::Schema;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-03-04'; # DATE
 our $DIST = 'Test-Sah-Schema'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -98,7 +98,7 @@ sub sah_schema_module_ok {
                                 my ($errmsg, $res)  = @{ $vdr->($value) };
                             if ($eg->{valid}) {
                                 if ($errmsg) {
-                                    $Test->ok(0, "Value should be valid, but isn't");
+                                    $Test->ok(0, "Value should be valid, but isn't ($errmsg)");
                                     $ok = 0;
                                     return;
                                 } else {
@@ -259,7 +259,7 @@ Test::Sah::Schema - Test Sah::Schema::* modules in distribution
 
 =head1 VERSION
 
-This document describes version 0.007 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-04.
+This document describes version 0.008 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-04.
 
 =head1 SYNOPSIS
 
